#[non_exhaustive]pub enum NavigationAction {
Continue,
Deny {
reason: String,
},
Redirect {
to: String,
reason: Option<String>,
},
}Expand description
Result of a navigation check (guard, lifecycle, or middleware).
Used by guards to allow/deny navigation, by lifecycle hooks to continue/abort, and as a general “what should the router do?” answer.
Example
use gpui_navigator::NavigationAction;
let action = NavigationAction::deny("Not authorized");
assert!(action.is_deny());
let action = NavigationAction::redirect("/login");
assert_eq!(action.redirect_path(), Some("/login"));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Continue
Allow navigation to proceed.
Deny
Deny navigation with a reason.
Redirect
Redirect to a different path.
Implementations
Sourcepub const fn allow() -> Self
pub const fn allow() -> Self
Create a result that allows navigation to proceed (alias for Continue).
Sourcepub fn deny(reason: impl Into<String>) -> Self
pub fn deny(reason: impl Into<String>) -> Self
Create a result that blocks navigation with a human-readable reason.
Sourcepub fn redirect(to: impl Into<String>) -> Self
pub fn redirect(to: impl Into<String>) -> Self
Create a result that redirects navigation to a different path.
Sourcepub fn redirect_with_reason(
to: impl Into<String>,
reason: impl Into<String>,
) -> Self
pub fn redirect_with_reason( to: impl Into<String>, reason: impl Into<String>, ) -> Self
Create a redirect result with a human-readable reason.
Sourcepub const fn is_continue(&self) -> bool
pub const fn is_continue(&self) -> bool
Check if this action allows navigation to continue.
Sourcepub const fn is_redirect(&self) -> bool
pub const fn is_redirect(&self) -> bool
Check if this action redirects navigation.
Sourcepub fn redirect_path(&self) -> Option<&str>
pub fn redirect_path(&self) -> Option<&str>
Get the redirect path, if this is a redirect action.